#version 330

uniform sampler2D blurredMoments;
uniform sampler2D texUnit;
uniform vec4 diffuse;
uniform vec4 lightDirection;
uniform int texCount;
uniform float minVariance = 0.0002;

in vec2 texCoordV;
in vec4 projShadowCoord;
in vec3 normalV, lightDir;
in vec4 pos;

out vec4 outColor;

void main()
{
	float shadowTerm=0;
	vec4 color, diff;

	if (texCount  != 2)
		diff = texture(texUnit, texCoordV) ;
	else 
		diff = diffuse;
		
	// ambient term = shadowed	
	color = diff * 0.25;
	
	vec3 n = normalize (normalV);
	
	float NdotL = max(0.0,dot (n, lightDir));
	
	float p=0;
	if (NdotL > 0.0) {
		vec4 proj = projShadowCoord / projShadowCoord.w; 
		vec2 moments = texture(blurredMoments, proj.xy).rg;
		if (proj.z <= moments.x) 
			shadowTerm = 1.0;
		else {
			float var = max(minVariance, moments.y - (moments.x * moments.x));
			float diff = proj.z - moments.x;
			shadowTerm = var / (var + diff*diff);
		}
		color += diff  * NdotL * shadowTerm ;
	}
	
	outColor = color;
}
